#--------------------------------------------------------------------
#----- GRNOC TL1 Ciena CN 4200 Device Module
#-----
#----- Copyright(C) 2010 The Trustees of Indiana University
#--------------------------------------------------------------------
#----- $HeadURL: svn+ssh://svn.grnoc.iu.edu/grnoc/perl-lib/GRNOC-TL1/tags/1.3.10/lib/GRNOC/TL1/Device/Ciena/CN4200.pm $
#----- $Id: CN4200.pm 11586 2011-03-22 20:20:18Z daldoyle $
#-----
#----- This module handles the functionality for the Ciena CN 4200
#----- TL1 device.  It inherts from the standard GRNOC::TL1::Device
#----- module.
#--------------------------------------------------------------------

package GRNOC::TL1::Device::Ciena::CN4200;
use base "GRNOC::TL1::Device";

use Data::Dumper;
use strict;

sub new {

  my $caller = shift;
  my $class = ref($caller) || $caller;
  
  my (%args) = @_;

  # set default port used for CN 4200s if one was not given
  $args{'port'} = 3083 if ($args{'port'} eq '');

  # set default prompt used for CN 4200s if one was not given
  $args{'prompt'} = ';' if ($args{'prompt'} eq '');

  # don't wait for a login prompt..
  $args{'wait_for_login_prompt'} = 0 if ($args{'wait_for_login_prompt'} eq '');

  # call the GRNOC::TL1::Device structure
  my $self = $class->SUPER::new(%args);

  bless($self, $class);
  
  return $self;
}

sub get_alarms {

  my $self = shift;

  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};

  # we need to send both a RTRV-ALM-ALL & RTRV-ALM-ENV
  my @cmds = ("RTRV-ALM-ALL:$tid" . "::$ctag" . "::,,;",
              "RTRV-ALM-ENV:$tid" . "::$ctag" . "::,;");

  my @alarms;

  foreach my $cmd (@cmds) {
  
    my $cmd_output = $self->cmd($cmd);
    return undef if (!defined $cmd_output);
   
    my @output_messages = $self->parse($cmd_output);
    my @responses = $self->get_responses(@output_messages);

    foreach my $response (@responses) {

      if ($response =~ /^"([^,]+),([^:]+):([^,]+),([^,]+),([^,]+),([^,]+),([^,]+),.*:(.*)"$/) {

        my $alarm;

        $alarm->{'aid'} = $1;
        $alarm->{'aid_type'} = $2;
        $alarm->{'not_code'} = $3;
        $alarm->{'cond_type'} = $4;
        $alarm->{'serv_affect'} = $5;
        $alarm->{'date'} = $6;
        $alarm->{'time'} = $7;
        $alarm->{'description'} = $8;

        # removed escaped quotes from alarm description
        $alarm->{'description'} =~ s/\\"//g;

        # split date into year month day (although they never seem to include year for some reason..)
        my @date = split(/-/, $alarm->{'date'});

        if (@date == 3) {
  
          ($alarm->{'year'}, $alarm->{'month'}, $alarm->{'day'}) = @date;
        }
   
        else {
  
 	  ($alarm->{'month'}, $alarm->{'day'}) = @date;
        }

        $alarm->{'time'} =~ s/-/:/g;

        push(@alarms, $alarm);
      }

      else {

        print STDERR "get_alarms: Error parsing alarm string: $response\n";
      }    
    }
  }

  return @alarms;
}

1;
