#--------------------------------------------------------------------
#----- GRNOC TL1 Glimmerglass GG1 Device Module
#-----
#----- Copyright(C) 2009 The Trustees of Indiana University
#--------------------------------------------------------------------
#----- $HeadURL: $
#----- $Id: $
#-----
#----- This module handles the functionality for the Glimmerglass GG1
#----- TL1 device.  It inherts from the standard
#----- GRNOC::TL1::Device module.
#--------------------------------------------------------------------

package GRNOC::TL1::Device::GlimmerGlass::GG1;
use base "GRNOC::TL1::Device";

use Data::Dumper;
use strict;

sub new {

  my $caller = shift;
  my $class = ref( $caller ) || $caller;

  my ( %args ) = @_;

  # set default port used for GG1 if one was not given
  $args{'port'} = 10033 if ( !$args{'port'} );
  $args{'prompt'} = '<' if ( !$args{'prompt'} );

  # call the GRNOC::TL1::Device structure
  my $self = $class->SUPER::new(%args);

  bless($self, $class);

  return $self;
}


sub add_cross_connect{

    my ($self,$in_port1, $in_port2, $out_port1,$out_port2) = @_;
    
    my $ctag = $self->{'ctag'};
    my $cmd = "ENT-CRS-FIBER::$in_port1&$in_port2,$out_port1&$out_port2:$ctag;";
    my $cmd_output = $self->cmd($cmd);
    return undef if (!defined $cmd_output);

    my ($output_message) = $self->parse($cmd_output);
    return $output_message->{'completion_code'} eq "COMPLD";
}

sub remove_cross_connect{

    my ($self,$in_port1, $in_port2) = @_;
    
    my $ctag = $self->{'ctag'};	
    my $cmd = "DLT-CRS-FIBER::$in_port1&$in_port2:$ctag;";
    my $cmd_output = $self->cmd($cmd);
    return undef if (!defined $cmd_output);

    my ($output_message) = $self->parse($cmd_output);
    return $output_message->{'completion_code'} eq "COMPLD";
}

sub remove_connect{
    
    my ($self,$port)  = @_;

    my $ctag = $self->{'ctag'};
    my $cmd = "DLT-CRS-FIBER::$port:$ctag;";
    my $cmd_output = $self->cmd($cmd);
    return undef if (!defined $cmd_output);

    my ($output_message) = $self->parse($cmd_output);
    return $output_message->{'completion_code'} eq "COMPLD";
}

1;
